%define anolis_release 5

Name:           libpsl
Version:        0.21.2
Release:        %{anolis_release}%{?dist}
Summary:        C library to handle the Publix Suffix List
License:        MIT
URL:            https://rockdaboot.github.io/%{name}
Source0:        https://github.com/rockdaboot/%{name}/releases/download/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  gcc make gtk-doc python3-devel gettext-devel glib2-devel
BuildRequires:  libicu-devel libidn2-devel libunistring-devel libxslt
BuildRequires:  publicsuffix-list
Requires:       publicsuffix-list-dafsa

%description
Libpsl is a C library to handle the Public Suffix List. A Public Suffix
List is a collection of Top Level Domains (TLDs) suffixes. TLDs include
Global Top Level Domains (gTLDs) like .com and .net; Country Top Level
Domains (ccTLDs) like .de and .cn; and Brand Top Level Domains like
.apple and .google. Brand TLDs allows users to register their own top
level domain that exist at the same level as ICANN's gTLDs. Brand TLDs
are sometimes referred to as Vanity Domains.


%package devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       publicsuffix-list

%description devel
This package contains libraries and header files for developing
applications that use %{name}.

%package -n psl
Summary:        Commandline utility to explore the Public Suffix List

%description -n psl
This package contains a commandline utility to explore the Public Suffix List,
for example it checks if domains are public suffixes, checks if cookie-domain
is acceptable for domains and so on.

%package -n psl-make-dafsa
Summary:        Compiles the Public Suffix List into DAFSA form

%description -n psl-make-dafsa
This script produces C/C++ code or an architecture-independent binary object
which represents a Deterministic Acyclic Finite State Automaton (DAFSA)
from a plain text Public Suffix List.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name}-devel = %{version}-%{release}
BuildArch:      noarch

%description doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -n %{name}-%{version} -p1
rm -frv list
ln -sv %{_datadir}/publicsuffix list
sed -i -e "1s|#!.*|#!%{__python3}|" src/psl-make-dafsa

%build
%configure --disable-silent-rules \
           --disable-static       \
           --enable-man           \
           --enable-gtk-doc       \
           --enable-builtin=libicu \
           --enable-runtime=libidn2 \
           --with-psl-distfile=%{_datadir}/publicsuffix/public_suffix_list.dafsa  \
           --with-psl-file=%{_datadir}/publicsuffix/effective_tld_names.dat       \
           --with-psl-testfile=%{_datadir}/publicsuffix/test_psl.txt

# avoid using rpath
sed -i libtool \
    -e 's|^\(runpath_var=\).*$|\1|' \
    -e 's|^\(hardcode_libdir_flag_spec=\).*$|\1|'

%make_build

%install
%make_install

# the script is noinst but the manpage is installed
install -m0755 src/psl-make-dafsa %{buildroot}%{_bindir}/

find %{buildroot} -name '*.la' -delete -print

%check
make check || cat tests/test-suite.log

%ldconfig_scriptlets

%generate_compatibility_deps

%files
%dir %{abidir}
%license COPYING
%{abidir}/%{name}*.dump
%{_libdir}/%{name}.so.5*

%files devel
%{_datadir}/gtk-doc/html/%{name}/
%{_includedir}/%{name}.h
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/%{name}.so
%{_mandir}/man3/%{name}.3*

%files -n psl
%license COPYING
%{abidir}/psl-option.list
%{_bindir}/psl
%{_mandir}/man1/psl.1*

%files -n psl-make-dafsa
%license COPYING
%{_bindir}/psl-make-dafsa
%{_mandir}/man1/psl-make-dafsa.1*

%files doc
%doc AUTHORS NEWS

%changelog
* Wed Mar 13 2024 dash <dash@nfschina.com> - 0.21.2-5
- update to 0.21.2

* Thu Apr 13 2023 Jing Zhang <renyu.zj@linux.alibaba.com> - 0.21.1-5
- Refact spec

* Thu Nov 24 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 0.21.1-4
- rebuild with libunistring update

* Mon Oct 24 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.21.1-3
- optimise spec file

* Fri Sep 30 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.21.1-2
- add doc package

* Wed Mar 02 2022 Hongwei Qin <qhw01063182@alibaba-inc.com> - 0.21.1-1
- upstream version 0.21.1
- Init for Anolis OS 23
